@@ -40,7 +40,7 @@ namespace Scripting
 Parley::Parley(EditorWindow * editor) : QObject(), m_editor(editor)
 {
     m_translator = new Translator(this); //parameter has to be <this> cause it's used by Translator to access callTranslateWord
-    m_doc = new Document(m_editor->m_mainWindow->parleyDocument()->document());
+    m_doc = new Document(m_editor->m_mainWindow->parleyDocument()->document().get());
 }
 
 Parley::~Parley()
